package ru.ulstu.user;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import ru.ulstu.model.User;
import ru.ulstu.model.UserSession;

@Service
@Transactional
public class UserSessionService {
    private final Logger log = LoggerFactory.getLogger(UserSessionService.class);
    private final UserSessionRepository userSessionRepository;
    private final UserService userService;

    public UserSessionService(UserSessionRepository userSessionRepository, UserService userService) {
        this.userSessionRepository = userSessionRepository;
        this.userService = userService;
    }

    public void createUserSession(String sessionId, String login, String ipAddress, String host) {
        final User user = userService.getUserByLogin(login);
        if (user == null) {
            throw new UserNotFoundException(login);
        }
        userSessionRepository.save(new UserSession(sessionId, ipAddress, host, user));
        log.debug("User session {} created for user {}@{} ({})", sessionId, login, ipAddress, host);
    }

    public void closeUserSession(String sessionId) {
        final UserSession userSession = userSessionRepository.findOneBySessionId(sessionId);
        if (userSession == null) {
            throw new IllegalArgumentException(String.format("User session %s not found", sessionId));
        }
        userSession.close();
        userSessionRepository.save(userSession);
        log.debug("User session {} closed", sessionId);
    }
}
